| Type | Project | Name | Status | Visibility | Updated | Field Matches | Actions
--- | --- | --- | --- | --- | --- | --- | --- | ---
{$ table.queryResponse.statusCode | queryStatus $}
| {$ hit._type | resourceLabeler $} | {$ hit._source.project_id | keystoneProjectName | noValue$} |  | {$ hit._source.status | commonStatus | noValue $} | {$ hit._type | commonVisibility: hit._source:table.userSession.project_id | noValue $} | {$ hit._source.updated_at | date:'short' | noValue $} | {$ hit._type | resourceLabeler: field $} |
{$ hit._type | resourceLabeler: field $}